@@ -3,7 +3,6 @@ import inspect
 import json
 import redis
 from jproperties import Properties
-import pandas as pd
 import logging
 import time
 import os
@@ -21,11 +20,12 @@ class Step:
         self.step = "St"
         self.paramsFile = 'Step.properties'
         self.logger = 'logStep'
-        self.logFile = self.getRelativeFile(os.getcwd() +'\../logs/Step.log')
+        self.logFile = self.getRelativeFile('../logs/Step.log')
 
     # Needed for relative paths
     def getRelativeFile(self, filename):
-        dirname = os.path.dirname(__file__)
+        # dirname = os.path.dirname(__file__) ## python directory should not be fetched  using __file__
+        dirname = sys.path[0] + '/'
         filename = os.path.join(dirname, filename)
         return filename
 
@@ -34,12 +34,13 @@ class Step:
         self.setTaskID()
         self.setUUID()
         self.params = self.trimPropertiesConfig(self.loadParams(self.paramsFile))
+        self.params = self.loadParams(self.paramsFile)
         self.nextStep = None
         if self.params["nextStep"]:
             self.nextStep = self.params["nextStep"].data
         self.setTaskExecutionID()
-        self.startRedisConn()
         self.setLogger(self.logger, self.logFile, logging.INFO)
+        self.startRedisConn()
         self.consensusID = self.taskID
         self.consensusExecutionID = self.taskExecutionID
         if ("consensusID" in self.params):
@@ -66,13 +67,13 @@ class Step:
     # Load parameters from file
     def loadParams(self, filename):
         configs = Properties()
-        filename = self.getRelativeFile(os.getcwd() + '\../params/' + filename)
+        filename = self.getRelativeFile('../params/' + filename)
         with open(filename, 'rb') as config_file:
             configs.load(config_file)
             config_file.close()
         return configs
 
-    # Trim keys and values in properties
+     # Trim keys and values in properties
     def trimPropertiesConfig(self, config: Properties) -> Properties:
         trimmedPropertiesFile = Properties()
         for properties in config:
@@ -104,13 +105,13 @@ class Step:
 
     # Reading taskID from text file
     def setTaskID(self):
-        with open(self.getRelativeFile(os.getcwd() +'\../params/Identifier.txt')) as f:
+        with open(self.getRelativeFile('../params/Identifier.txt')) as f:
             lines = f.readlines()
         self.taskID = lines[0]
         f.close()
 
-    # Storing the dataToHandoff in a dataframe and the converting  DF to json and printing it
-    # def handOff(self, rC, taskID, nextStep, dataToHandoff):
+    # Storing the datahandoff in a dataframe and the converting  DF to json and printing it
+    # def handOff(self, rC, taskID, step, datatohandoff):
     def handOff(self, dataToHandoff):
         try:
             self.logInfo("Handoff",self.taskID)
@@ -143,7 +144,7 @@ class Step:
                 return logdata
         except:
             print('logMessageFormat')
-            return 'None except'
+            return 'settaskExecutionId OR set step  went wrong , kindly recheck.'
 
     def exceptionTraceback(self):
         try:
@@ -156,6 +157,7 @@ class Step:
             stack_trace = list()
             for trace in trace_back:
                 stack_trace.append("File : %s , Line : %d, Message : %s" % (trace[0], trace[1], trace[3]))
+            # self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], str(str(ex_traceback) + ' ' + str(stack_trace))))
             return str(str(ex_traceback) + ' ' + str(stack_trace))
         except Exception as error:
             print('#######exceptionTraceback#### ' + str(error))
